@@ -2,8 +2,9 @@ import os
 import sys
 import unittest
 
-from executorlib.interactive.backend import parse_arguments
-from executorlib.shared.spawner import SrunSpawner, MpiExecSpawner
+from executorlib.standalone.interactive.backend import parse_arguments
+from executorlib.standalone.interactive.spawner import MpiExecSpawner
+from executorlib.interactive.slurm import SrunSpawner
 
 
 class TestParser(unittest.TestCase):
